@@ -39,7 +39,7 @@ The database is not garbage collected.
 
 =head1 SEE ALSO
 
-Mail::SRS
+L<Mail::SRS>
 
 =cut
 
